@@ -105,6 +105,7 @@ class AegisHandler(tornado.web.RequestHandler):
             user_agent = self.models['UserAgent'].get_id(user_agent['user_agent_id'])
         # Set up all robots to use the same user_id, based on the user-agent string, and don't bother with cookies.
         # Regular users just get tagged with a user cookie matching a row.
+        user = None
         if user_agent['robot_ind']:
             if not user_agent['robot_user_id']:
                 user_id = self.models['User'].insert(user_agent['user_agent_id'])
@@ -113,11 +114,13 @@ class AegisHandler(tornado.web.RequestHandler):
             user = self.models['User'].get_id(user_agent['robot_user_id'])
             user_ck = {}
         else:
+            # Check if the cookie exists, and if the record exists. If either doesn't exist, start a new user record.
             user_ck = self.cookie_get('user')
             if user_ck and user_ck.get('user_id'):
                 user = self.models['User'].get_id(user_ck['user_id'])
-                self.cookie_set('user', user_ck)
-            else:
+                if user:
+                    self.cookie_set('user', user_ck)
+            if not user:
                 user_id = self.models['User'].insert(user_agent['user_agent_id'])
                 user = self.models['User'].get_id(user_id)
                 if user_ck:
@@ -125,7 +128,8 @@ class AegisHandler(tornado.web.RequestHandler):
                 else:
                     user_ck = {'user_id': user_id}
                 self.cookie_set('user', user_ck)
-        self.tmpl['user']['user_id'] = user['user_id']
+        if user:
+            self.tmpl['user']['user_id'] = user['user_id']
 
     def user_is_robot(self):
         return bool(self.tmpl['user_agent_obj'].is_bot or aegis.stdlib.is_robot(self.tmpl['user_agent']))
@@ -524,7 +528,6 @@ class AegisHydraForm(AegisWeb):
     @tornado.web.authenticated
     def post(self, hydra_type_id=None, *args):
         self.enforce_admin()
-        self.logw(self.request.args, "ARGS")
         # Validate Input
         self.tmpl['errors'] = {}
         hydra_type = {}
@@ -532,8 +535,11 @@ class AegisHydraForm(AegisWeb):
         hydra_type['hydra_type_desc'] = self.request.args.get('hydra_type_desc')
         hydra_type['priority_ndx'] = aegis.stdlib.validate_int(self.request.args.get('priority_ndx'))
         hydra_type['next_run_sql'] = self.request.args.get('next_run_sql')
+        self.tmpl['hydra_type'] = hydra_type
+        if not hydra_type['hydra_type_name']:
+            self.tmpl['errors']['hydra_type_name'] = '** required (string)'
         if not hydra_type['priority_ndx']:
-            self.tmpl['errors']['priority_ndx'] = 'Must be an integer'
+            self.tmpl['errors']['priority_ndx'] = '** required (integer)'
         if self.tmpl['errors']:
             return self.render_path("hydra_form.html", **self.tmpl)
         # Run against database and send back to Hydra main
